@@ -192,8 +192,9 @@ void getoptions()
     getchar();
     uppercase(&ch);
     done = (ch == 'Y');
-   if (!done) {
-      if (strchr("DJOUNPG-LRSM01234",ch) != NULL) {
+    if (!done) {
+      if (((!usertree) && (strchr("DJOUNPG-LRSM01234", ch) != NULL))
+          || (usertree && ((strchr("DOUNPG-LRSM01234", ch) != NULL)))){
         switch (ch) {
 
         case 'D':
@@ -309,6 +310,8 @@ void doinit()
 
   inputnumbers2(&spp, &nonodes2, 1);
   getoptions();
+  if ( !usertree )
+    nonodes2--;
   alloctree(&curtree.nodep, nonodes2);
   allocd(nonodes2, curtree.nodep);
   allocw(nonodes2, curtree.nodep);
@@ -1019,7 +1022,7 @@ void maketree()
     which = 1;
     while (which <= numtrees) {
       treeread2 (intree, &curtree.start, curtree.nodep,
-        lengths, &trweight, &goteof, &haslengths, &spp);
+        lengths, &trweight, &goteof, &haslengths, &spp,false,nonodes2);
       nums = spp;
       curtree.start = curtree.nodep[outgrno - 1]->back;
       treevaluate();
@@ -1030,7 +1033,6 @@ void maketree()
     }
     FClose(intree);
   } else {
-    nonodes2--;
     if (jumb == 1) {
       inputdata(replicates, printdata, lower, upper, x, reps);
       setuptree(&curtree, nonodes2);
