@@ -35,7 +35,7 @@ void   maketree(void);
 
 Char infilename[FNMLNGTH], outfilename[FNMLNGTH], outtreename[FNMLNGTH], weightfilename[FNMLNGTH], ancfilename[FNMLNGTH], mixfilename[FNMLNGTH];
 node2 *root;
-long outgrno, rno, howmany, howoften, col, msets, ith;
+long outgrno, rno, howmanny, howoften, col, msets, ith;
 /*  outgrno indicates outgroup                                        */
 
 boolean weights, thresh, ancvar, questions, allsokal, allwagner,
@@ -73,7 +73,7 @@ void getoptions()
   fprintf(outfile, " branch-and-bound to find all");
   fprintf(outfile, " most parsimonious trees\n\n");
   howoften = often;
-  howmany = many;
+  howmanny = many;
   outgrno = 1;
   outgropt = false;
   simple = true;
@@ -103,7 +103,7 @@ void getoptions()
            (allwagner && !mixture)  ? "Wagner"       :
            (!(allwagner || mixture)) ? "Camin-Sokal"  : "(methods in mixture)");
     printf("  F        How often to report, in trees:%5ld\n",howoften);
-    printf("  H        How many groups of%5ld trees:%6ld\n",howoften,howmany);
+    printf("  H        How many groups of%5ld trees:%6ld\n",howoften,howmanny);
     printf("  O                        Outgroup root?");
     if (outgropt)
       printf("  Yes, at species number%3ld\n", outgrno);
@@ -172,7 +172,7 @@ void getoptions()
         break;
         
       case 'H':
-        inithowmany(&howmany, howoften);
+        inithowmany(&howmanny, howoften);
         break;
         
       case 'F':
@@ -490,7 +490,7 @@ void addtraverse(node2 *a, node2 *b, node2 *c, long *m, long *n,
     if (examined == howoften) {
       examined = 0;
       mults++;
-      if (mults == howmany)
+      if (mults == howmanny)
         done = true;
       if (progress) {
         printf("%6ld", mults);
